@@ -130,9 +130,14 @@ class ConsumerApp:
             return consumer
 
     def format_message(self, message) -> dict:
+
         schema_res = kafka.get_schema_from_registry(schema_registry=self._schema_registry, message=message, schema_cache=self._schema_cache)
-        schema = schema_res.json()["schema"]
-        decoded_message = kafka.decode_avro_message(schema, message)
+        try:
+            schema = schema_res.json()["schema"]
+        except KeyError:
+            decoded_message = json.loads(message.value)
+        else:
+            decoded_message = kafka.decode_avro_message(schema, message)
 
         return {"kafka_offset": message.offset,
                 "kafka_partition": message.partition,
